vsg_count: Count the number of VSGs in a group.

View source: R/vsg_count.R

vsg_countR Documentation

Count the number of VSGs in a group.

Description

Count the number of VSGs expressed in a designated group of parameters from a VSGSeq output results table.

Usage

vsg_count(df, ..., keep_all = FALSE)

Arguments

df

A data frame, usually containing VSGSeq results data.

...

A set of columns to 'group_by' and count the number of VSGs. These arguments are passed into dplyr::group_by function, then a dplyr::count function is applied.

keep_all

A logical argument. TRUE keeps all the rows and columns originally put into the function.

Value

Returns a date frame with the VSG counts based on the input group_by arguments.

Examples

vsg_count(results_df, mouse, tissue, day)
vsg_count(results_df, mouse, tissue, day, keep_all = TRUE)

ABeav/vsgseqtools documentation built on Jan. 26, 2024, 7:22 p.m.