| vsg_count | R Documentation |
Count the number of VSGs expressed in a designated group of parameters from a VSGSeq output results table.
vsg_count(df, ..., keep_all = FALSE)
df |
A data frame, usually containing VSGSeq results data. |
... |
A set of columns to 'group_by' and count the number of VSGs. These arguments are passed into dplyr::group_by function, then a dplyr::count function is applied. |
keep_all |
A logical argument. TRUE keeps all the rows and columns originally put into the function. |
Returns a date frame with the VSG counts based on the input group_by arguments.
vsg_count(results_df, mouse, tissue, day)
vsg_count(results_df, mouse, tissue, day, keep_all = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.